#ifndef LIBCARDFILE_H
#define LIBCARDFILE_H

#ifdef __cplusplus
extern "C" {
#endif 

#ifdef _MSC_VER
#define _CRT_SECURE_NO_WARNINGS
#endif 

#include <stdio.h>
#include <inttypes.h>
#include <stdlib.h>

/* Version */
#define LIBCARDFILE_VER					"0.1.0.0"
#define LIBCARDFILE_VER_MAJOR			0
#define LIBCARDFILE_VER_MINOR			1
#define LIBCARDFILE_VER_REVISION		0
#define LIBCARDFILE_VER_SUBREVISION		0
#ifdef DEBUG
/* Debug build type stuff goes here */
#endif 

#define SwapToBigEndian16bits(input) ((((input) >> 8) & 0x00ff) | (((input) << 8) & 0xff00))
#define SwapToBigEndian32bits(input) ((((input) >> 24) & 0x000000ff) | (((input) >> 8) & 0x0000ff00) | (((input) << 8) & 0x00ff0000) | (((input) << 24) & 0xff000000))

#define ERROR_UNKNOWN					-1
#define ERROR_OPENFILE_FAILED			-2
#define ERROR_UNSUPPORTED_FILETYPE		-3
#define ERROR_WRONG_CARDNUMBER			-4
#define ERROR_UNSUPPORTED_FEATURE		-5

const unsigned char header_MGC[] = {0x4d, 0x47, 0x43};
const unsigned char header_RRG[] = {0x52, 0x52, 0x47};
const unsigned char header_DKO[] = {0x44, 0x4b, 0x4f};

typedef struct tagCardFileHeader {
	unsigned char magic_number[3];
	uint32_t last_object;
	uint16_t number_cards;
} CARDFILEHEADER;
typedef struct tagCardFileIndex {
	unsigned char reserved[6];
	uint32_t card_data_pos;
	unsigned char flag;
	char index_title[40];
	unsigned char end_flag;
} CARDFILEINDEX, *PINDEX;

int GetFileType (FILE *fileptr);
int32_t GetLastObjectId (FILE *fileptr);
int GetCardsCount (FILE *fileptr);
PINDEX LoadCardNumberInfo (FILE *fileptr, int card_number);

//int ExportObject (const char *filename, int card_number, int object_id);
//char* GetCardData (const char*, int);
//char* GetIndexEntryData (const char* filename, int card_number);
//int GetCardDataPos (const char *filename);

#ifdef __cplusplus
}
#endif 

#endif 
